gawk-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gawk-diffs] [SCM] gawk branch, master, updated. gawk-4.1.0-1787-g44d565


From: Arnold Robbins
Subject: [gawk-diffs] [SCM] gawk branch, master, updated. gawk-4.1.0-1787-g44d5655
Date: Tue, 24 May 2016 22:38:09 +0000 (UTC)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "gawk".

The branch, master has been updated
       via  44d5655584bfa914c127f177919a7069e6cff841 (commit)
       via  5a66b6c262a2953af85465b1ec6c2d47bacec7cd (commit)
       via  6d42ef2758af7fa3fd8040e924c20b60a1d0cb4a (commit)
      from  ba52cf08f6d895a421c23b6f5f019d1b82da1f43 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.sv.gnu.org/cgit/gawk.git/commit/?id=44d5655584bfa914c127f177919a7069e6cff841

commit 44d5655584bfa914c127f177919a7069e6cff841
Author: Arnold D. Robbins <address@hidden>
Date:   Wed May 25 01:37:44 2016 +0300

    Add nonfatal error message facility to extension API.

diff --git a/ChangeLog b/ChangeLog
index 732d3ec..f92bf52 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2016-05-25         Manuel Collado        <address@hidden>.
+
+       * gawkapi.c (api_nonfatal): New function.
+       (api_impl): Include it.
+       * gawkapi.h (struct gawk_api): Add api_nonfatal member.
+       (nonfatal): New macro.
+
 2016-05-12         Arnold Robbins       <address@hidden>
 
        * str_array.c (str_lookup): Remove MAYBE_NUM from subscript flags.
diff --git a/NEWS b/NEWS
index 196dffd..d384c41 100644
--- a/NEWS
+++ b/NEWS
@@ -78,6 +78,9 @@ Changes from 4.1.x to 4.2.0
     disable optimizations so that the output program is the same as the
     original input program.
 
+20. The extension API now provides a mechanism for generating nonfatal
+    error messages.
+
 Changes from 4.1.3 to 4.1.4
 ---------------------------
 
diff --git a/doc/ChangeLog b/doc/ChangeLog
index 5d5d358..3210661 100644
--- a/doc/ChangeLog
+++ b/doc/ChangeLog
@@ -1,3 +1,7 @@
+2016-05-25         Manuel Collado        <address@hidden>.
+
+       * gawktexi.in: Document new 'nonfatal' API function.
+
 2016-05-25         Arnold D. Robbins     <address@hidden>
 
        * gawktexi.in: Typo fix in extension section, thanks to
diff --git a/doc/gawk.info b/doc/gawk.info
index 3060e5c..17310b1 100644
--- a/doc/gawk.info
+++ b/doc/gawk.info
@@ -24183,6 +24183,9 @@ extension ID received from 'gawk' when the extension 
was loaded:(1)
 'void fatal(awk_ext_id_t id, const char *format, ...);'
      Print a message and then cause 'gawk' to exit immediately.
 
+'void nonfatal(awk_ext_id_t id, const char *format, ...);'
+     Print a nonfatal error message.
+
 'void warning(awk_ext_id_t id, const char *format, ...);'
      Print a warning message.
 
@@ -26622,7 +26625,7 @@ File: gawk.info,  Node: Extension summary,  Next: 
Extension Exercises,  Prev: ga
           exit callbacks, a version string, input parsers, output
           wrappers, and two-way processors)
 
-        * Printing fatal, warning, and "lint" warning messages
+        * Printing fatal, nonfatal, warning, and "lint" warning messages
 
         * Updating 'ERRNO', or unsetting it
 
@@ -35694,128 +35697,128 @@ Node: Input Parsers966765
 Node: Output Wrappers976650
 Node: Two-way processors981162
 Node: Printing Messages983426
-Ref: Printing Messages-Footnote-1984500
-Node: Updating ERRNO984653
-Node: Requesting Values985392
-Ref: table-value-types-returned986129
-Node: Accessing Parameters987012
-Node: Symbol Table Access988247
-Node: Symbol table by name988759
-Node: Symbol table by cookie990780
-Ref: Symbol table by cookie-Footnote-1994929
-Node: Cached values994993
-Ref: Cached values-Footnote-1998494
-Node: Array Manipulation998585
-Ref: Array Manipulation-Footnote-1999676
-Node: Array Data Types999713
-Ref: Array Data Types-Footnote-11002371
-Node: Array Functions1002463
-Node: Flattening Arrays1006321
-Node: Creating Arrays1013229
-Node: Redirection API1017998
-Node: Extension API Variables1020829
-Node: Extension Versioning1021462
-Ref: gawk-api-version1021899
-Node: Extension API Informational Variables1023655
-Node: Extension API Boilerplate1024719
-Node: Finding Extensions1028533
-Node: Extension Example1029092
-Node: Internal File Description1029890
-Node: Internal File Ops1033970
-Ref: Internal File Ops-Footnote-11045732
-Node: Using Internal File Ops1045872
-Ref: Using Internal File Ops-Footnote-11048255
-Node: Extension Samples1048529
-Node: Extension Sample File Functions1050058
-Node: Extension Sample Fnmatch1057707
-Node: Extension Sample Fork1059194
-Node: Extension Sample Inplace1060412
-Node: Extension Sample Ord1063622
-Node: Extension Sample Readdir1064458
-Ref: table-readdir-file-types1065347
-Node: Extension Sample Revout1066152
-Node: Extension Sample Rev2way1066741
-Node: Extension Sample Read write array1067481
-Node: Extension Sample Readfile1069423
-Node: Extension Sample Time1070518
-Node: Extension Sample API Tests1071866
-Node: gawkextlib1072358
-Node: Extension summary1074805
-Node: Extension Exercises1078497
-Node: Language History1079994
-Node: V7/SVR3.11081650
-Node: SVR41083802
-Node: POSIX1085236
-Node: BTL1086615
-Node: POSIX/GNU1087344
-Node: Feature History1093206
-Node: Common Extensions1107576
-Node: Ranges and Locales1108859
-Ref: Ranges and Locales-Footnote-11113475
-Ref: Ranges and Locales-Footnote-21113502
-Ref: Ranges and Locales-Footnote-31113737
-Node: Contributors1113958
-Node: History summary1119527
-Node: Installation1120907
-Node: Gawk Distribution1121851
-Node: Getting1122335
-Node: Extracting1123296
-Node: Distribution contents1124934
-Node: Unix Installation1131028
-Node: Quick Installation1131710
-Node: Shell Startup Files1134124
-Node: Additional Configuration Options1135202
-Node: Configuration Philosophy1137007
-Node: Non-Unix Installation1139376
-Node: PC Installation1139834
-Node: PC Binary Installation1141154
-Node: PC Compiling1143006
-Ref: PC Compiling-Footnote-11146030
-Node: PC Testing1146139
-Node: PC Using1147319
-Node: Cygwin1151433
-Node: MSYS1152203
-Node: VMS Installation1152704
-Node: VMS Compilation1153495
-Ref: VMS Compilation-Footnote-11154724
-Node: VMS Dynamic Extensions1154782
-Node: VMS Installation Details1156467
-Node: VMS Running1158720
-Node: VMS GNV1162999
-Node: VMS Old Gawk1163734
-Node: Bugs1164205
-Node: Other Versions1168402
-Node: Installation summary1174986
-Node: Notes1176044
-Node: Compatibility Mode1176909
-Node: Additions1177691
-Node: Accessing The Source1178616
-Node: Adding Code1180051
-Node: New Ports1186270
-Node: Derived Files1190758
-Ref: Derived Files-Footnote-11196243
-Ref: Derived Files-Footnote-21196278
-Ref: Derived Files-Footnote-31196876
-Node: Future Extensions1196990
-Node: Implementation Limitations1197648
-Node: Extension Design1198831
-Node: Old Extension Problems1199985
-Ref: Old Extension Problems-Footnote-11201503
-Node: Extension New Mechanism Goals1201560
-Ref: Extension New Mechanism Goals-Footnote-11204924
-Node: Extension Other Design Decisions1205113
-Node: Extension Future Growth1207226
-Node: Old Extension Mechanism1208062
-Node: Notes summary1209825
-Node: Basic Concepts1211007
-Node: Basic High Level1211688
-Ref: figure-general-flow1211970
-Ref: figure-process-flow1212655
-Ref: Basic High Level-Footnote-11215956
-Node: Basic Data Typing1216141
-Node: Glossary1219469
-Node: Copying1251415
-Node: GNU Free Documentation License1288954
-Node: Index1314072
+Ref: Printing Messages-Footnote-1984597
+Node: Updating ERRNO984750
+Node: Requesting Values985489
+Ref: table-value-types-returned986226
+Node: Accessing Parameters987109
+Node: Symbol Table Access988344
+Node: Symbol table by name988856
+Node: Symbol table by cookie990877
+Ref: Symbol table by cookie-Footnote-1995026
+Node: Cached values995090
+Ref: Cached values-Footnote-1998591
+Node: Array Manipulation998682
+Ref: Array Manipulation-Footnote-1999773
+Node: Array Data Types999810
+Ref: Array Data Types-Footnote-11002468
+Node: Array Functions1002560
+Node: Flattening Arrays1006418
+Node: Creating Arrays1013326
+Node: Redirection API1018095
+Node: Extension API Variables1020926
+Node: Extension Versioning1021559
+Ref: gawk-api-version1021996
+Node: Extension API Informational Variables1023752
+Node: Extension API Boilerplate1024816
+Node: Finding Extensions1028630
+Node: Extension Example1029189
+Node: Internal File Description1029987
+Node: Internal File Ops1034067
+Ref: Internal File Ops-Footnote-11045829
+Node: Using Internal File Ops1045969
+Ref: Using Internal File Ops-Footnote-11048352
+Node: Extension Samples1048626
+Node: Extension Sample File Functions1050155
+Node: Extension Sample Fnmatch1057804
+Node: Extension Sample Fork1059291
+Node: Extension Sample Inplace1060509
+Node: Extension Sample Ord1063719
+Node: Extension Sample Readdir1064555
+Ref: table-readdir-file-types1065444
+Node: Extension Sample Revout1066249
+Node: Extension Sample Rev2way1066838
+Node: Extension Sample Read write array1067578
+Node: Extension Sample Readfile1069520
+Node: Extension Sample Time1070615
+Node: Extension Sample API Tests1071963
+Node: gawkextlib1072455
+Node: Extension summary1074902
+Node: Extension Exercises1078604
+Node: Language History1080101
+Node: V7/SVR3.11081757
+Node: SVR41083909
+Node: POSIX1085343
+Node: BTL1086722
+Node: POSIX/GNU1087451
+Node: Feature History1093313
+Node: Common Extensions1107683
+Node: Ranges and Locales1108966
+Ref: Ranges and Locales-Footnote-11113582
+Ref: Ranges and Locales-Footnote-21113609
+Ref: Ranges and Locales-Footnote-31113844
+Node: Contributors1114065
+Node: History summary1119634
+Node: Installation1121014
+Node: Gawk Distribution1121958
+Node: Getting1122442
+Node: Extracting1123403
+Node: Distribution contents1125041
+Node: Unix Installation1131135
+Node: Quick Installation1131817
+Node: Shell Startup Files1134231
+Node: Additional Configuration Options1135309
+Node: Configuration Philosophy1137114
+Node: Non-Unix Installation1139483
+Node: PC Installation1139941
+Node: PC Binary Installation1141261
+Node: PC Compiling1143113
+Ref: PC Compiling-Footnote-11146137
+Node: PC Testing1146246
+Node: PC Using1147426
+Node: Cygwin1151540
+Node: MSYS1152310
+Node: VMS Installation1152811
+Node: VMS Compilation1153602
+Ref: VMS Compilation-Footnote-11154831
+Node: VMS Dynamic Extensions1154889
+Node: VMS Installation Details1156574
+Node: VMS Running1158827
+Node: VMS GNV1163106
+Node: VMS Old Gawk1163841
+Node: Bugs1164312
+Node: Other Versions1168509
+Node: Installation summary1175093
+Node: Notes1176151
+Node: Compatibility Mode1177016
+Node: Additions1177798
+Node: Accessing The Source1178723
+Node: Adding Code1180158
+Node: New Ports1186377
+Node: Derived Files1190865
+Ref: Derived Files-Footnote-11196350
+Ref: Derived Files-Footnote-21196385
+Ref: Derived Files-Footnote-31196983
+Node: Future Extensions1197097
+Node: Implementation Limitations1197755
+Node: Extension Design1198938
+Node: Old Extension Problems1200092
+Ref: Old Extension Problems-Footnote-11201610
+Node: Extension New Mechanism Goals1201667
+Ref: Extension New Mechanism Goals-Footnote-11205031
+Node: Extension Other Design Decisions1205220
+Node: Extension Future Growth1207333
+Node: Old Extension Mechanism1208169
+Node: Notes summary1209932
+Node: Basic Concepts1211114
+Node: Basic High Level1211795
+Ref: figure-general-flow1212077
+Ref: figure-process-flow1212762
+Ref: Basic High Level-Footnote-11216063
+Node: Basic Data Typing1216248
+Node: Glossary1219576
+Node: Copying1251522
+Node: GNU Free Documentation License1289061
+Node: Index1314179
 
 End Tag Table
diff --git a/doc/gawk.texi b/doc/gawk.texi
index 5f5c4e2..9948b0f 100644
--- a/doc/gawk.texi
+++ b/doc/gawk.texi
@@ -33023,6 +33023,9 @@ that parameter. More's the pity.}
 @item void fatal(awk_ext_id_t id, const char *format, ...);
 Print a message and then cause @command{gawk} to exit immediately.
 
address@hidden void nonfatal(awk_ext_id_t id, const char *format, ...);
+Print a nonfatal error message.
+
 @item void warning(awk_ext_id_t id, const char *format, ...);
 Print a warning message.
 
@@ -35816,7 +35819,7 @@ output wrappers,
 and two-way processors)
 
 @item
-Printing fatal, warning, and ``lint'' warning messages
+Printing fatal, nonfatal, warning, and ``lint'' warning messages
 
 @item
 Updating @code{ERRNO}, or unsetting it
diff --git a/doc/gawktexi.in b/doc/gawktexi.in
index fac37bd..3182366 100644
--- a/doc/gawktexi.in
+++ b/doc/gawktexi.in
@@ -32114,6 +32114,9 @@ that parameter. More's the pity.}
 @item void fatal(awk_ext_id_t id, const char *format, ...);
 Print a message and then cause @command{gawk} to exit immediately.
 
address@hidden void nonfatal(awk_ext_id_t id, const char *format, ...);
+Print a nonfatal error message.
+
 @item void warning(awk_ext_id_t id, const char *format, ...);
 Print a warning message.
 
@@ -34907,7 +34910,7 @@ output wrappers,
 and two-way processors)
 
 @item
-Printing fatal, warning, and ``lint'' warning messages
+Printing fatal, nonfatal, warning, and ``lint'' warning messages
 
 @item
 Updating @code{ERRNO}, or unsetting it
diff --git a/gawkapi.h b/gawkapi.h
index bf6750d..3395990 100644
--- a/gawkapi.h
+++ b/gawkapi.h
@@ -710,6 +710,10 @@ typedef struct gawk_api {
                         */
                        const awk_input_buf_t **ibufp,
                        const awk_output_buf_t **obufp);
+
+       /* Print nonfatal error message */
+       void (*api_nonfatal)(awk_ext_id_t id, const char *format, ...);
+
 } gawk_api_t;
 
 #ifndef GAWK   /* these are not for the gawk code itself! */
@@ -731,6 +735,7 @@ typedef struct gawk_api {
        (api->api_set_argument(ext_id, count, new_array))
 
 #define fatal          api->api_fatal
+#define nonfatal       api->api_nonfatal
 #define warning                api->api_warning
 #define lintwarn       api->api_lintwarn
 

http://git.sv.gnu.org/cgit/gawk.git/commit/?id=5a66b6c262a2953af85465b1ec6c2d47bacec7cd

commit 5a66b6c262a2953af85465b1ec6c2d47bacec7cd
Merge: ba52cf0 6d42ef2
Author: Arnold D. Robbins <address@hidden>
Date:   Wed May 25 01:30:23 2016 +0300

    Merge branch 'gawk-4.1-stable'

diff --cc doc/gawk.info
index 248df6d,cdb4ea4..3060e5c
--- a/doc/gawk.info
+++ b/doc/gawk.info
@@@ -35255,567 -34674,562 +35255,567 @@@ Inde
  
  Tag Table:
  Node: Top1200
 -Node: Foreword342138
 -Node: Foreword446580
 -Node: Preface48112
 -Ref: Preface-Footnote-150984
 -Ref: Preface-Footnote-251091
 -Ref: Preface-Footnote-351325
 -Node: History51467
 -Node: Names53819
 -Ref: Names-Footnote-154913
 -Node: This Manual55060
 -Ref: This Manual-Footnote-161542
 -Node: Conventions61642
 -Node: Manual History63996
 -Ref: Manual History-Footnote-166991
 -Ref: Manual History-Footnote-267032
 -Node: How To Contribute67106
 -Node: Acknowledgments68235
 -Node: Getting Started73121
 -Node: Running gawk75560
 -Node: One-shot76750
 -Node: Read Terminal78013
 -Node: Long80045
 -Node: Executable Scripts81558
 -Ref: Executable Scripts-Footnote-184353
 -Node: Comments84456
 -Node: Quoting86940
 -Node: DOS Quoting92457
 -Node: Sample Data Files93132
 -Node: Very Simple95727
 -Node: Two Rules100629
 -Node: More Complex102514
 -Node: Statements/Lines105377
 -Ref: Statements/Lines-Footnote-1109836
 -Node: Other Features110101
 -Node: When111037
 -Ref: When-Footnote-1112791
 -Node: Intro Summary112856
 -Node: Invoking Gawk113740
 -Node: Command Line115254
 -Node: Options116052
 -Ref: Options-Footnote-1131959
 -Ref: Options-Footnote-2132189
 -Node: Other Arguments132214
 -Node: Naming Standard Input135161
 -Node: Environment Variables136254
 -Node: AWKPATH Variable136812
 -Ref: AWKPATH Variable-Footnote-1140113
 -Ref: AWKPATH Variable-Footnote-2140158
 -Node: AWKLIBPATH Variable140419
 -Node: Other Environment Variables141563
 -Node: Exit Status145328
 -Node: Include Files146005
 -Node: Loading Shared Libraries149600
 -Node: Obsolete151028
 -Node: Undocumented151720
 -Node: Invoking Summary152017
 -Node: Regexp153677
 -Node: Regexp Usage155131
 -Node: Escape Sequences157168
 -Node: Regexp Operators163182
 -Ref: Regexp Operators-Footnote-1170598
 -Ref: Regexp Operators-Footnote-2170745
 -Node: Bracket Expressions170843
 -Ref: table-char-classes173319
 -Node: Leftmost Longest176456
 -Node: Computed Regexps177759
 -Node: GNU Regexp Operators181186
 -Node: Case-sensitivity184865
 -Ref: Case-sensitivity-Footnote-1187752
 -Ref: Case-sensitivity-Footnote-2187987
 -Node: Regexp Summary188095
 -Node: Reading Files189561
 -Node: Records191655
 -Node: awk split records192388
 -Node: gawk split records197319
 -Ref: gawk split records-Footnote-1201859
 -Node: Fields201896
 -Ref: Fields-Footnote-1204676
 -Node: Nonconstant Fields204762
 -Ref: Nonconstant Fields-Footnote-1206998
 -Node: Changing Fields207202
 -Node: Field Separators213130
 -Node: Default Field Splitting215828
 -Node: Regexp Field Splitting216946
 -Node: Single Character Fields220299
 -Node: Command Line Field Separator221359
 -Node: Full Line Fields224577
 -Ref: Full Line Fields-Footnote-1226099
 -Ref: Full Line Fields-Footnote-2226145
 -Node: Field Splitting Summary226246
 -Node: Constant Size228320
 -Node: Splitting By Content232898
 -Ref: Splitting By Content-Footnote-1236869
 -Node: Multiple Line237032
 -Ref: Multiple Line-Footnote-1242914
 -Node: Getline243093
 -Node: Plain Getline245297
 -Node: Getline/Variable247936
 -Node: Getline/File249085
 -Node: Getline/Variable/File250471
 -Ref: Getline/Variable/File-Footnote-1252074
 -Node: Getline/Pipe252162
 -Node: Getline/Variable/Pipe254867
 -Node: Getline/Coprocess256000
 -Node: Getline/Variable/Coprocess257265
 -Node: Getline Notes258005
 -Node: Getline Summary260800
 -Ref: table-getline-variants261222
 -Node: Read Timeout261970
 -Ref: Read Timeout-Footnote-1265811
 -Node: Command-line directories265869
 -Node: Input Summary266773
 -Node: Input Exercises269945
 -Node: Printing270673
 -Node: Print272449
 -Node: Print Examples273906
 -Node: Output Separators276686
 -Node: OFMT278703
 -Node: Printf280059
 -Node: Basic Printf280844
 -Node: Control Letters282418
 -Node: Format Modifiers286406
 -Node: Printf Examples292421
 -Node: Redirection294907
 -Node: Special FD301748
 -Ref: Special FD-Footnote-1304916
 -Node: Special Files304990
 -Node: Other Inherited Files305607
 -Node: Special Network306608
 -Node: Special Caveats307468
 -Node: Close Files And Pipes308417
 -Ref: Close Files And Pipes-Footnote-1315610
 -Ref: Close Files And Pipes-Footnote-2315758
 -Node: Output Summary315909
 -Node: Output Exercises316907
 -Node: Expressions317586
 -Node: Values318774
 -Node: Constants319452
 -Node: Scalar Constants320143
 -Ref: Scalar Constants-Footnote-1321007
 -Node: Nondecimal-numbers321257
 -Node: Regexp Constants324270
 -Node: Using Constant Regexps324796
 -Node: Variables327959
 -Node: Using Variables328616
 -Node: Assignment Options330526
 -Node: Conversion332399
 -Node: Strings And Numbers332923
 -Ref: Strings And Numbers-Footnote-1335986
 -Node: Locale influences conversions336095
 -Ref: table-locale-affects338853
 -Node: All Operators339471
 -Node: Arithmetic Ops340100
 -Node: Concatenation342606
 -Ref: Concatenation-Footnote-1345453
 -Node: Assignment Ops345560
 -Ref: table-assign-ops350551
 -Node: Increment Ops351864
 -Node: Truth Values and Conditions355324
 -Node: Truth Values356398
 -Node: Typing and Comparison357446
 -Node: Variable Typing358266
 -Node: Comparison Operators361890
 -Ref: table-relational-ops362309
 -Node: POSIX String Comparison365804
 -Ref: POSIX String Comparison-Footnote-1366878
 -Node: Boolean Ops367017
 -Ref: Boolean Ops-Footnote-1371499
 -Node: Conditional Exp371591
 -Node: Function Calls373327
 -Node: Precedence377204
 -Node: Locales380863
 -Node: Expressions Summary382495
 -Node: Patterns and Actions385068
 -Node: Pattern Overview386188
 -Node: Regexp Patterns387865
 -Node: Expression Patterns388407
 -Node: Ranges392188
 -Node: BEGIN/END395296
 -Node: Using BEGIN/END396057
 -Ref: Using BEGIN/END-Footnote-1398793
 -Node: I/O And BEGIN/END398899
 -Node: BEGINFILE/ENDFILE401213
 -Node: Empty404120
 -Node: Using Shell Variables404437
 -Node: Action Overview406711
 -Node: Statements409036
 -Node: If Statement410884
 -Node: While Statement412379
 -Node: Do Statement414407
 -Node: For Statement415555
 -Node: Switch Statement418713
 -Node: Break Statement421099
 -Node: Continue Statement423191
 -Node: Next Statement425018
 -Node: Nextfile Statement427401
 -Node: Exit Statement430053
 -Node: Built-in Variables432456
 -Node: User-modified433589
 -Ref: User-modified-Footnote-1441214
 -Node: Auto-set441276
 -Ref: Auto-set-Footnote-1454366
 -Ref: Auto-set-Footnote-2454572
 -Node: ARGC and ARGV454628
 -Node: Pattern Action Summary458841
 -Node: Arrays461271
 -Node: Array Basics462600
 -Node: Array Intro463444
 -Ref: figure-array-elements465419
 -Ref: Array Intro-Footnote-1468123
 -Node: Reference to Elements468251
 -Node: Assigning Elements470715
 -Node: Array Example471206
 -Node: Scanning an Array472965
 -Node: Controlling Scanning475987
 -Ref: Controlling Scanning-Footnote-1481386
 -Node: Numeric Array Subscripts481702
 -Node: Uninitialized Subscripts483886
 -Node: Delete485505
 -Ref: Delete-Footnote-1488257
 -Node: Multidimensional488314
 -Node: Multiscanning491409
 -Node: Arrays of Arrays493000
 -Node: Arrays Summary497767
 -Node: Functions499860
 -Node: Built-in500898
 -Node: Calling Built-in501976
 -Node: Numeric Functions503972
 -Ref: Numeric Functions-Footnote-1508000
 -Ref: Numeric Functions-Footnote-2508357
 -Ref: Numeric Functions-Footnote-3508405
 -Node: String Functions508677
 -Ref: String Functions-Footnote-1532181
 -Ref: String Functions-Footnote-2532309
 -Ref: String Functions-Footnote-3532557
 -Node: Gory Details532644
 -Ref: table-sub-escapes534435
 -Ref: table-sub-proposed535954
 -Ref: table-posix-sub537317
 -Ref: table-gensub-escapes538858
 -Ref: Gory Details-Footnote-1539681
 -Node: I/O Functions539832
 -Ref: table-system-return-values546414
 -Ref: I/O Functions-Footnote-1548394
 -Ref: I/O Functions-Footnote-2548542
 -Node: Time Functions548662
 -Ref: Time Functions-Footnote-1559167
 -Ref: Time Functions-Footnote-2559235
 -Ref: Time Functions-Footnote-3559393
 -Ref: Time Functions-Footnote-4559504
 -Ref: Time Functions-Footnote-5559616
 -Ref: Time Functions-Footnote-6559843
 -Node: Bitwise Functions560109
 -Ref: table-bitwise-ops560703
 -Ref: Bitwise Functions-Footnote-1565041
 -Node: Type Functions565214
 -Node: I18N Functions566370
 -Node: User-defined568021
 -Node: Definition Syntax568826
 -Ref: Definition Syntax-Footnote-1574513
 -Node: Function Example574584
 -Ref: Function Example-Footnote-1577506
 -Node: Function Caveats577528
 -Node: Calling A Function578046
 -Node: Variable Scope579004
 -Node: Pass By Value/Reference581998
 -Node: Return Statement585497
 -Node: Dynamic Typing588476
 -Node: Indirect Calls589406
 -Ref: Indirect Calls-Footnote-1599657
 -Node: Functions Summary599785
 -Node: Library Functions602490
 -Ref: Library Functions-Footnote-1606097
 -Ref: Library Functions-Footnote-2606240
 -Node: Library Names606411
 -Ref: Library Names-Footnote-1609871
 -Ref: Library Names-Footnote-2610094
 -Node: General Functions610180
 -Node: Strtonum Function611283
 -Node: Assert Function614305
 -Node: Round Function617631
 -Node: Cliff Random Function619172
 -Node: Ordinal Functions620188
 -Ref: Ordinal Functions-Footnote-1623251
 -Ref: Ordinal Functions-Footnote-2623503
 -Node: Join Function623713
 -Ref: Join Function-Footnote-1625483
 -Node: Getlocaltime Function625683
 -Node: Readfile Function629425
 -Node: Shell Quoting631397
 -Node: Data File Management632798
 -Node: Filetrans Function633430
 -Node: Rewind Function637526
 -Node: File Checking639431
 -Ref: File Checking-Footnote-1640765
 -Node: Empty Files640966
 -Node: Ignoring Assigns642945
 -Node: Getopt Function644495
 -Ref: Getopt Function-Footnote-1655964
 -Node: Passwd Functions656164
 -Ref: Passwd Functions-Footnote-1665003
 -Node: Group Functions665091
 -Ref: Group Functions-Footnote-1672988
 -Node: Walking Arrays673195
 -Node: Library Functions Summary676203
 -Node: Library Exercises677609
 -Node: Sample Programs678074
 -Node: Running Examples678844
 -Node: Clones679572
 -Node: Cut Program680796
 -Node: Egrep Program690725
 -Ref: Egrep Program-Footnote-1698237
 -Node: Id Program698347
 -Node: Split Program702027
 -Ref: Split Program-Footnote-1705486
 -Node: Tee Program705615
 -Node: Uniq Program708405
 -Node: Wc Program715831
 -Ref: Wc Program-Footnote-1720086
 -Node: Miscellaneous Programs720180
 -Node: Dupword Program721393
 -Node: Alarm Program723423
 -Node: Translate Program728278
 -Ref: Translate Program-Footnote-1732843
 -Node: Labels Program733113
 -Ref: Labels Program-Footnote-1736464
 -Node: Word Sorting736548
 -Node: History Sorting740620
 -Node: Extract Program742455
 -Node: Simple Sed749984
 -Node: Igawk Program753058
 -Ref: Igawk Program-Footnote-1767389
 -Ref: Igawk Program-Footnote-2767591
 -Ref: Igawk Program-Footnote-3767713
 -Node: Anagram Program767828
 -Node: Signature Program770890
 -Node: Programs Summary772137
 -Node: Programs Exercises773351
 -Ref: Programs Exercises-Footnote-1777480
 -Node: Advanced Features777571
 -Node: Nondecimal Data779561
 -Node: Array Sorting781152
 -Node: Controlling Array Traversal781852
 -Ref: Controlling Array Traversal-Footnote-1790219
 -Node: Array Sorting Functions790337
 -Ref: Array Sorting Functions-Footnote-1795428
 -Node: Two-way I/O795624
 -Ref: Two-way I/O-Footnote-1801918
 -Ref: Two-way I/O-Footnote-2802105
 -Node: TCP/IP Networking802187
 -Node: Profiling805305
 -Node: Advanced Features Summary812844
 -Node: Internationalization814780
 -Node: I18N and L10N816260
 -Node: Explaining gettext816947
 -Ref: Explaining gettext-Footnote-1821970
 -Ref: Explaining gettext-Footnote-2822155
 -Node: Programmer i18n822320
 -Ref: Programmer i18n-Footnote-1827175
 -Node: Translator i18n827224
 -Node: String Extraction828018
 -Ref: String Extraction-Footnote-1829150
 -Node: Printf Ordering829236
 -Ref: Printf Ordering-Footnote-1832022
 -Node: I18N Portability832086
 -Ref: I18N Portability-Footnote-1834542
 -Node: I18N Example834605
 -Ref: I18N Example-Footnote-1837411
 -Node: Gawk I18N837484
 -Node: I18N Summary838129
 -Node: Debugger839470
 -Node: Debugging840492
 -Node: Debugging Concepts840933
 -Node: Debugging Terms842742
 -Node: Awk Debugging845317
 -Node: Sample Debugging Session846223
 -Node: Debugger Invocation846757
 -Node: Finding The Bug848143
 -Node: List of Debugger Commands854621
 -Node: Breakpoint Control855954
 -Node: Debugger Execution Control859648
 -Node: Viewing And Changing Data863010
 -Node: Execution Stack866384
 -Node: Debugger Info868021
 -Node: Miscellaneous Debugger Commands872092
 -Node: Readline Support877180
 -Node: Limitations878076
 -Node: Debugging Summary880185
 -Node: Arbitrary Precision Arithmetic881358
 -Node: Computer Arithmetic882774
 -Ref: table-numeric-ranges886365
 -Ref: Computer Arithmetic-Footnote-1887087
 -Node: Math Definitions887144
 -Ref: table-ieee-formats890458
 -Ref: Math Definitions-Footnote-1891061
 -Node: MPFR features891166
 -Node: FP Math Caution892883
 -Ref: FP Math Caution-Footnote-1893955
 -Node: Inexactness of computations894324
 -Node: Inexact representation895284
 -Node: Comparing FP Values896644
 -Node: Errors accumulate897726
 -Node: Getting Accuracy899159
 -Node: Try To Round901869
 -Node: Setting precision902768
 -Ref: table-predefined-precision-strings903465
 -Node: Setting the rounding mode905295
 -Ref: table-gawk-rounding-modes905669
 -Ref: Setting the rounding mode-Footnote-1909077
 -Node: Arbitrary Precision Integers909256
 -Ref: Arbitrary Precision Integers-Footnote-1912240
 -Node: POSIX Floating Point Problems912389
 -Ref: POSIX Floating Point Problems-Footnote-1916271
 -Node: Floating point summary916309
 -Node: Dynamic Extensions918499
 -Node: Extension Intro920052
 -Node: Plugin License921318
 -Node: Extension Mechanism Outline922115
 -Ref: figure-load-extension922554
 -Ref: figure-register-new-function924119
 -Ref: figure-call-new-function925211
 -Node: Extension API Description927273
 -Node: Extension API Functions Introduction928721
 -Node: General Data Types933533
 -Ref: General Data Types-Footnote-1939488
 -Node: Memory Allocation Functions939787
 -Ref: Memory Allocation Functions-Footnote-1942632
 -Node: Constructor Functions942731
 -Node: Registration Functions944476
 -Node: Extension Functions945161
 -Node: Exit Callback Functions947460
 -Node: Extension Version String948710
 -Node: Input Parsers949373
 -Node: Output Wrappers959258
 -Node: Two-way processors963770
 -Node: Printing Messages966034
 -Ref: Printing Messages-Footnote-1967108
 -Node: Updating ERRNO967261
 -Node: Requesting Values968000
 -Ref: table-value-types-returned968737
 -Node: Accessing Parameters969620
 -Node: Symbol Table Access970855
 -Node: Symbol table by name971367
 -Node: Symbol table by cookie973388
 -Ref: Symbol table by cookie-Footnote-1977537
 -Node: Cached values977601
 -Ref: Cached values-Footnote-1981102
 -Node: Array Manipulation981193
 -Ref: Array Manipulation-Footnote-1982292
 -Node: Array Data Types982329
 -Ref: Array Data Types-Footnote-1984987
 -Node: Array Functions985079
 -Node: Flattening Arrays988937
 -Node: Creating Arrays995845
 -Node: Extension API Variables1000614
 -Node: Extension Versioning1001250
 -Ref: gawk-api-version1001687
 -Node: Extension API Informational Variables1003443
 -Node: Extension API Boilerplate1004507
 -Node: Finding Extensions1008321
 -Node: Extension Example1008880
 -Node: Internal File Description1009678
 -Node: Internal File Ops1013758
 -Ref: Internal File Ops-Footnote-11025520
 -Node: Using Internal File Ops1025660
 -Ref: Using Internal File Ops-Footnote-11028043
 -Node: Extension Samples1028317
 -Node: Extension Sample File Functions1029846
 -Node: Extension Sample Fnmatch1037495
 -Node: Extension Sample Fork1038982
 -Node: Extension Sample Inplace1040200
 -Node: Extension Sample Ord1043410
 -Node: Extension Sample Readdir1044246
 -Ref: table-readdir-file-types1045135
 -Node: Extension Sample Revout1045940
 -Node: Extension Sample Rev2way1046529
 -Node: Extension Sample Read write array1047269
 -Node: Extension Sample Readfile1049211
 -Node: Extension Sample Time1050306
 -Node: Extension Sample API Tests1051654
 -Node: gawkextlib1052146
 -Node: Extension summary1054570
 -Node: Extension Exercises1058262
 -Node: Language History1059759
 -Node: V7/SVR3.11061415
 -Node: SVR41063567
 -Node: POSIX1065001
 -Node: BTL1066380
 -Node: POSIX/GNU1067109
 -Node: Feature History1072630
 -Node: Common Extensions1085959
 -Node: Ranges and Locales1087242
 -Ref: Ranges and Locales-Footnote-11091858
 -Ref: Ranges and Locales-Footnote-21091885
 -Ref: Ranges and Locales-Footnote-31092120
 -Node: Contributors1092341
 -Node: History summary1097910
 -Node: Installation1099290
 -Node: Gawk Distribution1100234
 -Node: Getting1100718
 -Node: Extracting1101679
 -Node: Distribution contents1103317
 -Node: Unix Installation1109068
 -Node: Quick Installation1109684
 -Node: Additional Configuration Options1112111
 -Node: Configuration Philosophy1113915
 -Node: Non-Unix Installation1116284
 -Node: PC Installation1116742
 -Node: PC Binary Installation1118062
 -Node: PC Compiling1119914
 -Ref: PC Compiling-Footnote-11122938
 -Node: PC Testing1123047
 -Node: PC Using1124227
 -Node: Cygwin1128341
 -Node: MSYS1129111
 -Node: VMS Installation1129612
 -Node: VMS Compilation1130403
 -Ref: VMS Compilation-Footnote-11131632
 -Node: VMS Dynamic Extensions1131690
 -Node: VMS Installation Details1133375
 -Node: VMS Running1135628
 -Node: VMS GNV1139907
 -Node: VMS Old Gawk1140642
 -Node: Bugs1141113
 -Node: Other Versions1145310
 -Node: Installation summary1151894
 -Node: Notes1152952
 -Node: Compatibility Mode1153817
 -Node: Additions1154599
 -Node: Accessing The Source1155524
 -Node: Adding Code1156959
 -Node: New Ports1163178
 -Node: Derived Files1167666
 -Ref: Derived Files-Footnote-11173151
 -Ref: Derived Files-Footnote-21173186
 -Ref: Derived Files-Footnote-31173784
 -Node: Future Extensions1173898
 -Node: Implementation Limitations1174556
 -Node: Extension Design1175739
 -Node: Old Extension Problems1176893
 -Ref: Old Extension Problems-Footnote-11178411
 -Node: Extension New Mechanism Goals1178468
 -Ref: Extension New Mechanism Goals-Footnote-11181832
 -Node: Extension Other Design Decisions1182021
 -Node: Extension Future Growth1184134
 -Node: Old Extension Mechanism1184970
 -Node: Notes summary1186733
 -Node: Basic Concepts1187915
 -Node: Basic High Level1188596
 -Ref: figure-general-flow1188878
 -Ref: figure-process-flow1189563
 -Ref: Basic High Level-Footnote-11192864
 -Node: Basic Data Typing1193049
 -Node: Glossary1196377
 -Node: Copying1228323
 -Node: GNU Free Documentation License1265862
 -Node: Index1290980
 +Node: Foreword342506
 +Node: Foreword446948
 +Node: Preface48480
 +Ref: Preface-Footnote-151352
 +Ref: Preface-Footnote-251459
 +Ref: Preface-Footnote-351693
 +Node: History51835
 +Node: Names54187
 +Ref: Names-Footnote-155281
 +Node: This Manual55428
 +Ref: This Manual-Footnote-161910
 +Node: Conventions62010
 +Node: Manual History64364
 +Ref: Manual History-Footnote-167359
 +Ref: Manual History-Footnote-267400
 +Node: How To Contribute67474
 +Node: Acknowledgments68603
 +Node: Getting Started73489
 +Node: Running gawk75928
 +Node: One-shot77118
 +Node: Read Terminal78381
 +Node: Long80413
 +Node: Executable Scripts81926
 +Ref: Executable Scripts-Footnote-184721
 +Node: Comments84824
 +Node: Quoting87308
 +Node: DOS Quoting92825
 +Node: Sample Data Files93500
 +Node: Very Simple96095
 +Node: Two Rules100997
 +Node: More Complex102882
 +Node: Statements/Lines105745
 +Ref: Statements/Lines-Footnote-1110204
 +Node: Other Features110469
 +Node: When111405
 +Ref: When-Footnote-1113159
 +Node: Intro Summary113224
 +Node: Invoking Gawk114108
 +Node: Command Line115622
 +Node: Options116420
 +Ref: Options-Footnote-1132518
 +Ref: Options-Footnote-2132748
 +Node: Other Arguments132773
 +Node: Naming Standard Input135720
 +Node: Environment Variables136813
 +Node: AWKPATH Variable137371
 +Ref: AWKPATH Variable-Footnote-1140782
 +Ref: AWKPATH Variable-Footnote-2140827
 +Node: AWKLIBPATH Variable141088
 +Node: Other Environment Variables142345
 +Node: Exit Status145983
 +Node: Include Files146660
 +Node: Loading Shared Libraries150255
 +Node: Obsolete151683
 +Node: Undocumented152375
 +Node: Invoking Summary152672
 +Node: Regexp154332
 +Node: Regexp Usage155851
 +Node: Escape Sequences157888
 +Node: Regexp Operators164120
 +Ref: Regexp Operators-Footnote-1171536
 +Ref: Regexp Operators-Footnote-2171683
 +Node: Bracket Expressions171781
 +Ref: table-char-classes174257
 +Node: Leftmost Longest177394
 +Node: Computed Regexps178697
 +Node: GNU Regexp Operators182124
 +Node: Case-sensitivity185803
 +Ref: Case-sensitivity-Footnote-1188699
 +Ref: Case-sensitivity-Footnote-2188934
 +Node: Strong Regexp Constants189042
 +Node: Regexp Summary191984
 +Node: Reading Files193590
 +Node: Records195753
 +Node: awk split records196486
 +Node: gawk split records201417
 +Ref: gawk split records-Footnote-1205957
 +Node: Fields205994
 +Node: Nonconstant Fields208735
 +Ref: Nonconstant Fields-Footnote-1210971
 +Node: Changing Fields211175
 +Node: Field Separators217103
 +Node: Default Field Splitting219801
 +Node: Regexp Field Splitting220919
 +Node: Single Character Fields224272
 +Node: Command Line Field Separator225332
 +Node: Full Line Fields228550
 +Ref: Full Line Fields-Footnote-1230072
 +Ref: Full Line Fields-Footnote-2230118
 +Node: Field Splitting Summary230219
 +Node: Constant Size232293
 +Node: Splitting By Content236871
 +Ref: Splitting By Content-Footnote-1240842
 +Node: Multiple Line241005
 +Ref: Multiple Line-Footnote-1246887
 +Node: Getline247066
 +Node: Plain Getline249532
 +Node: Getline/Variable252171
 +Node: Getline/File253320
 +Node: Getline/Variable/File254706
 +Ref: Getline/Variable/File-Footnote-1256309
 +Node: Getline/Pipe256397
 +Node: Getline/Variable/Pipe259102
 +Node: Getline/Coprocess260235
 +Node: Getline/Variable/Coprocess261500
 +Node: Getline Notes262240
 +Node: Getline Summary265035
 +Ref: table-getline-variants265457
 +Node: Read Timeout266205
 +Ref: Read Timeout-Footnote-1270111
 +Node: Retrying Input270169
 +Node: Command-line directories271368
 +Node: Input Summary272274
 +Node: Input Exercises275446
 +Node: Printing276174
 +Node: Print278008
 +Node: Print Examples279465
 +Node: Output Separators282245
 +Node: OFMT284262
 +Node: Printf285618
 +Node: Basic Printf286403
 +Node: Control Letters287977
 +Node: Format Modifiers291965
 +Node: Printf Examples297980
 +Node: Redirection300466
 +Node: Special FD307307
 +Ref: Special FD-Footnote-1310475
 +Node: Special Files310549
 +Node: Other Inherited Files311166
 +Node: Special Network312167
 +Node: Special Caveats313027
 +Node: Close Files And Pipes313976
 +Ref: Close Files And Pipes-Footnote-1321163
 +Ref: Close Files And Pipes-Footnote-2321311
 +Node: Nonfatal321462
 +Node: Output Summary323787
 +Node: Output Exercises325009
 +Node: Expressions325688
 +Node: Values326876
 +Node: Constants327554
 +Node: Scalar Constants328245
 +Ref: Scalar Constants-Footnote-1329109
 +Node: Nondecimal-numbers329359
 +Node: Regexp Constants332372
 +Node: Using Constant Regexps332898
 +Node: Variables336061
 +Node: Using Variables336718
 +Node: Assignment Options338628
 +Node: Conversion340501
 +Node: Strings And Numbers341025
 +Ref: Strings And Numbers-Footnote-1344088
 +Node: Locale influences conversions344197
 +Ref: table-locale-affects346955
 +Node: All Operators347573
 +Node: Arithmetic Ops348202
 +Node: Concatenation350708
 +Ref: Concatenation-Footnote-1353555
 +Node: Assignment Ops353662
 +Ref: table-assign-ops358653
 +Node: Increment Ops359966
 +Node: Truth Values and Conditions363426
 +Node: Truth Values364500
 +Node: Typing and Comparison365548
 +Node: Variable Typing366368
 +Node: Comparison Operators369992
 +Ref: table-relational-ops370411
 +Node: POSIX String Comparison373906
 +Ref: POSIX String Comparison-Footnote-1374980
 +Node: Boolean Ops375119
 +Ref: Boolean Ops-Footnote-1379601
 +Node: Conditional Exp379693
 +Node: Function Calls381429
 +Node: Precedence385306
 +Node: Locales388965
 +Node: Expressions Summary390597
 +Node: Patterns and Actions393170
 +Node: Pattern Overview394290
 +Node: Regexp Patterns395967
 +Node: Expression Patterns396509
 +Node: Ranges400290
 +Node: BEGIN/END403398
 +Node: Using BEGIN/END404159
 +Ref: Using BEGIN/END-Footnote-1406895
 +Node: I/O And BEGIN/END407001
 +Node: BEGINFILE/ENDFILE409315
 +Node: Empty412222
 +Node: Using Shell Variables412539
 +Node: Action Overview414813
 +Node: Statements417138
 +Node: If Statement418986
 +Node: While Statement420481
 +Node: Do Statement422509
 +Node: For Statement423657
 +Node: Switch Statement426815
 +Node: Break Statement429201
 +Node: Continue Statement431293
 +Node: Next Statement433120
 +Node: Nextfile Statement435503
 +Node: Exit Statement438155
 +Node: Built-in Variables440558
 +Node: User-modified441691
 +Node: Auto-set449277
 +Ref: Auto-set-Footnote-1463664
 +Ref: Auto-set-Footnote-2463870
 +Node: ARGC and ARGV463926
 +Node: Pattern Action Summary468139
 +Node: Arrays470569
 +Node: Array Basics471898
 +Node: Array Intro472742
 +Ref: figure-array-elements474717
 +Ref: Array Intro-Footnote-1477421
 +Node: Reference to Elements477549
 +Node: Assigning Elements480013
 +Node: Array Example480504
 +Node: Scanning an Array482263
 +Node: Controlling Scanning485285
 +Ref: Controlling Scanning-Footnote-1490684
 +Node: Numeric Array Subscripts491000
 +Node: Uninitialized Subscripts493184
 +Node: Delete494803
 +Ref: Delete-Footnote-1497555
 +Node: Multidimensional497612
 +Node: Multiscanning500707
 +Node: Arrays of Arrays502298
 +Node: Arrays Summary507065
 +Node: Functions509158
 +Node: Built-in510196
 +Node: Calling Built-in511274
 +Node: Numeric Functions513270
 +Ref: Numeric Functions-Footnote-1518103
 +Ref: Numeric Functions-Footnote-2518460
 +Ref: Numeric Functions-Footnote-3518508
 +Node: String Functions518780
 +Ref: String Functions-Footnote-1542284
 +Ref: String Functions-Footnote-2542412
 +Ref: String Functions-Footnote-3542660
 +Node: Gory Details542747
 +Ref: table-sub-escapes544538
 +Ref: table-sub-proposed546057
 +Ref: table-posix-sub547420
 +Ref: table-gensub-escapes548961
 +Ref: Gory Details-Footnote-1549784
 +Node: I/O Functions549935
 +Ref: table-system-return-values556517
 +Ref: I/O Functions-Footnote-1558497
 +Ref: I/O Functions-Footnote-2558645
 +Node: Time Functions558765
 +Ref: Time Functions-Footnote-1569270
 +Ref: Time Functions-Footnote-2569338
 +Ref: Time Functions-Footnote-3569496
 +Ref: Time Functions-Footnote-4569607
 +Ref: Time Functions-Footnote-5569719
 +Ref: Time Functions-Footnote-6569946
 +Node: Bitwise Functions570212
 +Ref: table-bitwise-ops570806
 +Ref: Bitwise Functions-Footnote-1575144
 +Node: Type Functions575317
 +Node: I18N Functions577978
 +Node: User-defined579629
 +Node: Definition Syntax580434
 +Ref: Definition Syntax-Footnote-1586121
 +Node: Function Example586192
 +Ref: Function Example-Footnote-1589114
 +Node: Function Caveats589136
 +Node: Calling A Function589654
 +Node: Variable Scope590612
 +Node: Pass By Value/Reference593606
 +Node: Return Statement597105
 +Node: Dynamic Typing600084
 +Node: Indirect Calls601014
 +Ref: Indirect Calls-Footnote-1611265
 +Node: Functions Summary611393
 +Node: Library Functions614098
 +Ref: Library Functions-Footnote-1617705
 +Ref: Library Functions-Footnote-2617848
 +Node: Library Names618019
 +Ref: Library Names-Footnote-1621479
 +Ref: Library Names-Footnote-2621702
 +Node: General Functions621788
 +Node: Strtonum Function622891
 +Node: Assert Function625913
 +Node: Round Function629239
 +Node: Cliff Random Function630780
 +Node: Ordinal Functions631796
 +Ref: Ordinal Functions-Footnote-1634859
 +Ref: Ordinal Functions-Footnote-2635111
 +Node: Join Function635321
 +Ref: Join Function-Footnote-1637091
 +Node: Getlocaltime Function637291
 +Node: Readfile Function641033
 +Node: Shell Quoting643005
 +Node: Data File Management644406
 +Node: Filetrans Function645038
 +Node: Rewind Function649134
 +Node: File Checking651039
 +Ref: File Checking-Footnote-1652373
 +Node: Empty Files652574
 +Node: Ignoring Assigns654553
 +Node: Getopt Function656103
 +Ref: Getopt Function-Footnote-1667572
 +Node: Passwd Functions667772
 +Ref: Passwd Functions-Footnote-1676611
 +Node: Group Functions676699
 +Ref: Group Functions-Footnote-1684596
 +Node: Walking Arrays684803
 +Node: Library Functions Summary687811
 +Node: Library Exercises689217
 +Node: Sample Programs689682
 +Node: Running Examples690452
 +Node: Clones691180
 +Node: Cut Program692404
 +Node: Egrep Program702333
 +Ref: Egrep Program-Footnote-1709845
 +Node: Id Program709955
 +Node: Split Program713635
 +Ref: Split Program-Footnote-1717094
 +Node: Tee Program717223
 +Node: Uniq Program720013
 +Node: Wc Program727439
 +Ref: Wc Program-Footnote-1731694
 +Node: Miscellaneous Programs731788
 +Node: Dupword Program733001
 +Node: Alarm Program735031
 +Node: Translate Program739886
 +Ref: Translate Program-Footnote-1744451
 +Node: Labels Program744721
 +Ref: Labels Program-Footnote-1748072
 +Node: Word Sorting748156
 +Node: History Sorting752228
 +Node: Extract Program754063
 +Node: Simple Sed761592
 +Node: Igawk Program764666
 +Ref: Igawk Program-Footnote-1778997
 +Ref: Igawk Program-Footnote-2779199
 +Ref: Igawk Program-Footnote-3779321
 +Node: Anagram Program779436
 +Node: Signature Program782498
 +Node: Programs Summary783745
 +Node: Programs Exercises784959
 +Ref: Programs Exercises-Footnote-1789088
 +Node: Advanced Features789179
 +Node: Nondecimal Data791169
 +Node: Array Sorting792760
 +Node: Controlling Array Traversal793460
 +Ref: Controlling Array Traversal-Footnote-1801827
 +Node: Array Sorting Functions801945
 +Ref: Array Sorting Functions-Footnote-1807036
 +Node: Two-way I/O807232
 +Ref: Two-way I/O-Footnote-1813782
 +Ref: Two-way I/O-Footnote-2813969
 +Node: TCP/IP Networking814051
 +Node: Profiling817169
 +Ref: Profiling-Footnote-1825662
 +Node: Advanced Features Summary825985
 +Node: Internationalization827829
 +Node: I18N and L10N829309
 +Node: Explaining gettext829996
 +Ref: Explaining gettext-Footnote-1835019
 +Ref: Explaining gettext-Footnote-2835204
 +Node: Programmer i18n835369
 +Ref: Programmer i18n-Footnote-1840224
 +Node: Translator i18n840273
 +Node: String Extraction841067
 +Ref: String Extraction-Footnote-1842199
 +Node: Printf Ordering842285
 +Ref: Printf Ordering-Footnote-1845071
 +Node: I18N Portability845135
 +Ref: I18N Portability-Footnote-1847591
 +Node: I18N Example847654
 +Ref: I18N Example-Footnote-1850460
 +Node: Gawk I18N850533
 +Node: I18N Summary851178
 +Node: Debugger852519
 +Node: Debugging853541
 +Node: Debugging Concepts853982
 +Node: Debugging Terms855791
 +Node: Awk Debugging858366
 +Node: Sample Debugging Session859272
 +Node: Debugger Invocation859806
 +Node: Finding The Bug861192
 +Node: List of Debugger Commands867670
 +Node: Breakpoint Control869003
 +Node: Debugger Execution Control872697
 +Node: Viewing And Changing Data876059
 +Node: Execution Stack879433
 +Node: Debugger Info881070
 +Node: Miscellaneous Debugger Commands885141
 +Node: Readline Support890229
 +Node: Limitations891125
 +Ref: Limitations-Footnote-1895356
 +Node: Debugging Summary895407
 +Node: Arbitrary Precision Arithmetic896686
 +Node: Computer Arithmetic898102
 +Ref: table-numeric-ranges901693
 +Ref: Computer Arithmetic-Footnote-1902415
 +Node: Math Definitions902472
 +Ref: table-ieee-formats905786
 +Ref: Math Definitions-Footnote-1906389
 +Node: MPFR features906494
 +Node: FP Math Caution908211
 +Ref: FP Math Caution-Footnote-1909283
 +Node: Inexactness of computations909652
 +Node: Inexact representation910612
 +Node: Comparing FP Values911972
 +Node: Errors accumulate913054
 +Node: Getting Accuracy914487
 +Node: Try To Round917197
 +Node: Setting precision918096
 +Ref: table-predefined-precision-strings918793
 +Node: Setting the rounding mode920623
 +Ref: table-gawk-rounding-modes920997
 +Ref: Setting the rounding mode-Footnote-1924405
 +Node: Arbitrary Precision Integers924584
 +Ref: Arbitrary Precision Integers-Footnote-1929501
 +Node: POSIX Floating Point Problems929650
 +Ref: POSIX Floating Point Problems-Footnote-1933532
 +Node: Floating point summary933570
 +Node: Dynamic Extensions935760
 +Node: Extension Intro937313
 +Node: Plugin License938579
 +Node: Extension Mechanism Outline939376
 +Ref: figure-load-extension939815
 +Ref: figure-register-new-function941380
 +Ref: figure-call-new-function942472
 +Node: Extension API Description944534
 +Node: Extension API Functions Introduction946066
 +Node: General Data Types950925
 +Ref: General Data Types-Footnote-1956880
 +Node: Memory Allocation Functions957179
 +Ref: Memory Allocation Functions-Footnote-1960024
 +Node: Constructor Functions960123
 +Node: Registration Functions961868
 +Node: Extension Functions962553
 +Node: Exit Callback Functions964852
 +Node: Extension Version String966102
 +Node: Input Parsers966765
 +Node: Output Wrappers976650
 +Node: Two-way processors981162
 +Node: Printing Messages983426
 +Ref: Printing Messages-Footnote-1984500
 +Node: Updating ERRNO984653
 +Node: Requesting Values985392
 +Ref: table-value-types-returned986129
 +Node: Accessing Parameters987012
 +Node: Symbol Table Access988247
 +Node: Symbol table by name988759
 +Node: Symbol table by cookie990780
 +Ref: Symbol table by cookie-Footnote-1994929
 +Node: Cached values994993
 +Ref: Cached values-Footnote-1998494
 +Node: Array Manipulation998585
 +Ref: Array Manipulation-Footnote-1999676
 +Node: Array Data Types999713
 +Ref: Array Data Types-Footnote-11002371
 +Node: Array Functions1002463
 +Node: Flattening Arrays1006321
 +Node: Creating Arrays1013229
- Node: Redirection API1018000
- Node: Extension API Variables1020831
- Node: Extension Versioning1021464
- Ref: gawk-api-version1021901
- Node: Extension API Informational Variables1023657
- Node: Extension API Boilerplate1024721
- Node: Finding Extensions1028535
- Node: Extension Example1029094
- Node: Internal File Description1029892
- Node: Internal File Ops1033972
- Ref: Internal File Ops-Footnote-11045734
- Node: Using Internal File Ops1045874
- Ref: Using Internal File Ops-Footnote-11048257
- Node: Extension Samples1048531
- Node: Extension Sample File Functions1050060
- Node: Extension Sample Fnmatch1057709
- Node: Extension Sample Fork1059196
- Node: Extension Sample Inplace1060414
- Node: Extension Sample Ord1063624
- Node: Extension Sample Readdir1064460
- Ref: table-readdir-file-types1065349
- Node: Extension Sample Revout1066154
- Node: Extension Sample Rev2way1066743
- Node: Extension Sample Read write array1067483
- Node: Extension Sample Readfile1069425
- Node: Extension Sample Time1070520
- Node: Extension Sample API Tests1071868
- Node: gawkextlib1072360
- Node: Extension summary1074807
- Node: Extension Exercises1078499
- Node: Language History1079996
- Node: V7/SVR3.11081652
- Node: SVR41083804
- Node: POSIX1085238
- Node: BTL1086617
- Node: POSIX/GNU1087346
- Node: Feature History1093208
- Node: Common Extensions1107578
- Node: Ranges and Locales1108861
- Ref: Ranges and Locales-Footnote-11113477
- Ref: Ranges and Locales-Footnote-21113504
- Ref: Ranges and Locales-Footnote-31113739
- Node: Contributors1113960
- Node: History summary1119529
- Node: Installation1120909
- Node: Gawk Distribution1121853
- Node: Getting1122337
- Node: Extracting1123298
- Node: Distribution contents1124936
- Node: Unix Installation1131030
- Node: Quick Installation1131712
- Node: Shell Startup Files1134126
- Node: Additional Configuration Options1135204
- Node: Configuration Philosophy1137009
- Node: Non-Unix Installation1139378
- Node: PC Installation1139836
- Node: PC Binary Installation1141156
- Node: PC Compiling1143008
- Ref: PC Compiling-Footnote-11146032
- Node: PC Testing1146141
- Node: PC Using1147321
- Node: Cygwin1151435
- Node: MSYS1152205
- Node: VMS Installation1152706
- Node: VMS Compilation1153497
- Ref: VMS Compilation-Footnote-11154726
- Node: VMS Dynamic Extensions1154784
- Node: VMS Installation Details1156469
- Node: VMS Running1158722
- Node: VMS GNV1163001
- Node: VMS Old Gawk1163736
- Node: Bugs1164207
- Node: Other Versions1168404
- Node: Installation summary1174988
- Node: Notes1176046
- Node: Compatibility Mode1176911
- Node: Additions1177693
- Node: Accessing The Source1178618
- Node: Adding Code1180053
- Node: New Ports1186272
- Node: Derived Files1190760
- Ref: Derived Files-Footnote-11196245
- Ref: Derived Files-Footnote-21196280
- Ref: Derived Files-Footnote-31196878
- Node: Future Extensions1196992
- Node: Implementation Limitations1197650
- Node: Extension Design1198833
- Node: Old Extension Problems1199987
- Ref: Old Extension Problems-Footnote-11201505
- Node: Extension New Mechanism Goals1201562
- Ref: Extension New Mechanism Goals-Footnote-11204926
- Node: Extension Other Design Decisions1205115
- Node: Extension Future Growth1207228
- Node: Old Extension Mechanism1208064
- Node: Notes summary1209827
- Node: Basic Concepts1211009
- Node: Basic High Level1211690
- Ref: figure-general-flow1211972
- Ref: figure-process-flow1212657
- Ref: Basic High Level-Footnote-11215958
- Node: Basic Data Typing1216143
- Node: Glossary1219471
- Node: Copying1251417
- Node: GNU Free Documentation License1288956
- Node: Index1314074
++Node: Redirection API1017998
++Node: Extension API Variables1020829
++Node: Extension Versioning1021462
++Ref: gawk-api-version1021899
++Node: Extension API Informational Variables1023655
++Node: Extension API Boilerplate1024719
++Node: Finding Extensions1028533
++Node: Extension Example1029092
++Node: Internal File Description1029890
++Node: Internal File Ops1033970
++Ref: Internal File Ops-Footnote-11045732
++Node: Using Internal File Ops1045872
++Ref: Using Internal File Ops-Footnote-11048255
++Node: Extension Samples1048529
++Node: Extension Sample File Functions1050058
++Node: Extension Sample Fnmatch1057707
++Node: Extension Sample Fork1059194
++Node: Extension Sample Inplace1060412
++Node: Extension Sample Ord1063622
++Node: Extension Sample Readdir1064458
++Ref: table-readdir-file-types1065347
++Node: Extension Sample Revout1066152
++Node: Extension Sample Rev2way1066741
++Node: Extension Sample Read write array1067481
++Node: Extension Sample Readfile1069423
++Node: Extension Sample Time1070518
++Node: Extension Sample API Tests1071866
++Node: gawkextlib1072358
++Node: Extension summary1074805
++Node: Extension Exercises1078497
++Node: Language History1079994
++Node: V7/SVR3.11081650
++Node: SVR41083802
++Node: POSIX1085236
++Node: BTL1086615
++Node: POSIX/GNU1087344
++Node: Feature History1093206
++Node: Common Extensions1107576
++Node: Ranges and Locales1108859
++Ref: Ranges and Locales-Footnote-11113475
++Ref: Ranges and Locales-Footnote-21113502
++Ref: Ranges and Locales-Footnote-31113737
++Node: Contributors1113958
++Node: History summary1119527
++Node: Installation1120907
++Node: Gawk Distribution1121851
++Node: Getting1122335
++Node: Extracting1123296
++Node: Distribution contents1124934
++Node: Unix Installation1131028
++Node: Quick Installation1131710
++Node: Shell Startup Files1134124
++Node: Additional Configuration Options1135202
++Node: Configuration Philosophy1137007
++Node: Non-Unix Installation1139376
++Node: PC Installation1139834
++Node: PC Binary Installation1141154
++Node: PC Compiling1143006
++Ref: PC Compiling-Footnote-11146030
++Node: PC Testing1146139
++Node: PC Using1147319
++Node: Cygwin1151433
++Node: MSYS1152203
++Node: VMS Installation1152704
++Node: VMS Compilation1153495
++Ref: VMS Compilation-Footnote-11154724
++Node: VMS Dynamic Extensions1154782
++Node: VMS Installation Details1156467
++Node: VMS Running1158720
++Node: VMS GNV1162999
++Node: VMS Old Gawk1163734
++Node: Bugs1164205
++Node: Other Versions1168402
++Node: Installation summary1174986
++Node: Notes1176044
++Node: Compatibility Mode1176909
++Node: Additions1177691
++Node: Accessing The Source1178616
++Node: Adding Code1180051
++Node: New Ports1186270
++Node: Derived Files1190758
++Ref: Derived Files-Footnote-11196243
++Ref: Derived Files-Footnote-21196278
++Ref: Derived Files-Footnote-31196876
++Node: Future Extensions1196990
++Node: Implementation Limitations1197648
++Node: Extension Design1198831
++Node: Old Extension Problems1199985
++Ref: Old Extension Problems-Footnote-11201503
++Node: Extension New Mechanism Goals1201560
++Ref: Extension New Mechanism Goals-Footnote-11204924
++Node: Extension Other Design Decisions1205113
++Node: Extension Future Growth1207226
++Node: Old Extension Mechanism1208062
++Node: Notes summary1209825
++Node: Basic Concepts1211007
++Node: Basic High Level1211688
++Ref: figure-general-flow1211970
++Ref: figure-process-flow1212655
++Ref: Basic High Level-Footnote-11215956
++Node: Basic Data Typing1216141
++Node: Glossary1219469
++Node: Copying1251415
++Node: GNU Free Documentation License1288954
++Node: Index1314072
  
  End Tag Table

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog       |    7 ++
 NEWS            |    3 +
 doc/ChangeLog   |    9 ++
 doc/gawk.info   |  253 ++++++++++++++++++++++++++++---------------------------
 doc/gawk.texi   |    7 +-
 doc/gawktexi.in |    7 +-
 gawkapi.c       |   19 ++++-
 gawkapi.h       |    5 ++
 8 files changed, 180 insertions(+), 130 deletions(-)


hooks/post-receive
diff --git a/gawkapi.c b/gawkapi.c
index 9d8c6f3..9d5f449 100644
--- a/gawkapi.c
+++ b/gawkapi.c
@@ -198,7 +198,21 @@ api_fatal(awk_ext_id_t id, const char *format, ...)
        va_end(args);
 }
 
-/* api_warning --- print a warning message and exit */
+/* api_nonfatal --- print a non fatal error message */
+
+static void
+api_nonfatal(awk_ext_id_t id, const char *format, ...)
+{
+       va_list args;
+
+       (void) id;
+
+       va_start(args, format);
+       err(false, _("error: "), format, args);
+       va_end(args);
+}
+
+/* api_warning --- print a warning message */
 
 static void
 api_warning(awk_ext_id_t id, const char *format, ...)
@@ -1222,6 +1236,9 @@ gawk_api_t api_impl = {
 
        /* Find/open a file */
        api_get_file,
+
+       /* Print nonfatal error message */
+       api_nonfatal,
 };
 
 /* init_ext_api --- init the extension API */
-- 
gawk



reply via email to

[Prev in Thread] Current Thread [Next in Thread]